@@ -1,15 +1,18 @@
 """ TimeAtlas API Definition """
 
 from timeatlas import abstract
+from timeatlas import detectors
+from timeatlas import generators
 from timeatlas.metadata import Metadata
+from timeatlas import metrics
+from timeatlas import plots
+from timeatlas import processors
+from timeatlas.read_write import (
+    read_pickle,
+    read_text,
+    read_tsd,
+    csv_to_tsd
+)
 from timeatlas.time_series import TimeSeries
 from timeatlas.time_series_dataset import TimeSeriesDataset
-from timeatlas import metrics
-from timeatlas import processing
 from timeatlas import types
-from timeatlas.io import (
-    read_pickle,
-    read_text
-)
-
-from timeatlas.generators import AnomalyGenerator, AnomalyGeneratorTemplate
