@@ -1,5 +1,5 @@
 from .surprise import Surprise
 
 __all__ = [
-    "Surprise",
-]
\ No newline at end of file
+    'Surprise',
+]
