@@ -1,7 +1,8 @@
-from .base_dataset import BaseDataset
-from timeatlas import TimeSeriesDataset
 import numpy as np
 
+from .base_dataset import BaseDataset
+from timeatlas.time_series_dataset import TimeSeriesDataset
+
 
 class TimeSeriesClassificationDataset(BaseDataset):
     """
