@@ -1,7 +1,9 @@
-from .unit import Unit
+from .coords import Coords
 from .sensor import Sensor
+from .unit import Unit
 
 __all__ = [
+    "Coords",
+    "Sensor",
     "Unit",
-    "Sensor"
 ]
