@@ -4,6 +4,12 @@ import pickle
 
 
 def ensure_dir(file_path: str) -> NoReturn:
+    """
+    Make sure that a path to a directory exists, or creates its directory leafs
+
+    Args:
+        file_path: the path to the file/directory
+    """
     directory = os.path.dirname(file_path)
     if not os.path.exists(directory):
         os.makedirs(directory)
@@ -19,4 +25,4 @@ def to_pickle(obj: Any, path: str) -> NoReturn:
     """
     ensure_dir(path)
     with open(path, 'wb') as file:
-        pickle.dump(obj, file, pickle.HIGHEST_PROTOCOL)
\ No newline at end of file
+        pickle.dump(obj, file, pickle.HIGHEST_PROTOCOL)
